@@ -38,6 +38,26 @@ class BaseObject:
                 self.cacheTask = asyncio.get_event_loop().create_task(self.__cinit__())
             else:
                 self.__cinit__()
+        elif hasattr(self, "__cinit__"):
+            if str(type(self.client)) == "<class 'vrcpy.client.AClient'>":
+                async def di1(self):
+                    async def di2(self):
+                        raise AttributeError(self.objType + " object has no attribute 'do_init'")
+
+                    if asyncio.iscoroutinefunction(self.__cinit__):
+                        await self.__cinit__()
+                    else:
+                        self.__cinit__()
+
+                    self.do_init = di2
+            else:
+                def di1(self):
+                    def di2(self):
+                        raise AttributeError(self.objType + " object has no attribute 'do_init'")
+
+                    self.__cinit__()
+                    self.do_init = di2
+            self.do_init = di1
 
         self._dict = obj
 
@@ -78,6 +98,13 @@ class Avatar(BaseObject):
             "favoriteId": self.id, "tags": ["avatars1"]})
         return Favorite(self.client, resp["data"])
 
+    def select(self):
+        '''
+        Selects this avatar to be used/worn
+        '''
+
+        self.client.api.call("/avatars/{}/select".format(self.id), "PUT")
+
     def __init__(self, client, obj):
         super().__init__(client)
         self.unique += [
@@ -177,6 +204,14 @@ class User(LimitedUser):
 class CurrentUser(User):
     objType = "CurrentUser"
 
+    def fetch_full(self):
+        user = LimitedUser.fetch_full(self)
+        return user
+
+    def public_avatars(self):
+        avatars = LimitedUser.public_avatars(self)
+        return avatars
+
     def unfriend(self):
         raise AttributeError("'CurrentUser' object has no attribute 'unfriend'")
 
@@ -237,17 +272,20 @@ class CurrentUser(User):
         self.client.me = CurrentUser(self.client, resp["data"])
         return self.client.me
 
-    def fetch_favorites(self, t):
+    def fetch_favorites(self, t, n: int = 100):
         '''
         Used to get favorites
 
             t, string
             FavoriteType
 
+            n, integer
+            Max number of favorites to return (Most that will ever return is 100)
+
         Returns list of Favorite objects
         '''
 
-        resp = self.client.api.call("/favorites", params={"type": t, "n": 50})
+        resp = self.client.api.call("/favorites", params={"type": t, "n": n})
 
         f = []
         for favorite in resp["data"]:
